==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/maintenance/kotlin/inputs/InputWindowsParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.maintenance.kotlin.inputs

import com.pulumi.azurenative.maintenance.inputs.InputWindowsParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Input properties for patching a Windows machine.
 * @property classificationsToInclude Classification category of patches to be patched
 * @property excludeKbsRequiringReboot Exclude patches which need reboot
 * @property kbNumbersToExclude Windows KBID to be excluded for patching.
 * @property kbNumbersToInclude Windows KBID to be included for patching.
 */
public data class InputWindowsParametersArgs(
    public val classificationsToInclude: Output<List<String>>? = null,
    public val excludeKbsRequiringReboot: Output<Boolean>? = null,
    public val kbNumbersToExclude: Output<List<String>>? = null,
    public val kbNumbersToInclude: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.maintenance.inputs.InputWindowsParametersArgs> {
    override fun toJava(): com.pulumi.azurenative.maintenance.inputs.InputWindowsParametersArgs =
        com.pulumi.azurenative.maintenance.inputs.InputWindowsParametersArgs.builder()
            .classificationsToInclude(
                classificationsToInclude?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .excludeKbsRequiringReboot(excludeKbsRequiringReboot?.applyValue({ args0 -> args0 }))
            .kbNumbersToExclude(kbNumbersToExclude?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .kbNumbersToInclude(
                kbNumbersToInclude?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [InputWindowsParametersArgs].
 */
@PulumiTagMarker
public class InputWindowsParametersArgsBuilder internal constructor() {
    private var classificationsToInclude: Output<List<String>>? = null

    private var excludeKbsRequiringReboot: Output<Boolean>? = null

    private var kbNumbersToExclude: Output<List<String>>? = null

    private var kbNumbersToInclude: Output<List<String>>? = null

    /**
     * @param value Classification category of patches to be patched
     */
    @JvmName("iqrmxvmsgflinqxs")
    public suspend fun classificationsToInclude(`value`: Output<List<String>>) {
        this.classificationsToInclude = value
    }

    @JvmName("ekognfrnqbaajehl")
    public suspend fun classificationsToInclude(vararg values: Output<String>) {
        this.classificationsToInclude = Output.all(values.asList())
    }

    /**
     * @param values Classification category of patches to be patched
     */
    @JvmName("xfxqrqjkytnvmyws")
    public suspend fun classificationsToInclude(values: List<Output<String>>) {
        this.classificationsToInclude = Output.all(values)
    }

    /**
     * @param value Exclude patches which need reboot
     */
    @JvmName("wdbbakaaeeslnmkk")
    public suspend fun excludeKbsRequiringReboot(`value`: Output<Boolean>) {
        this.excludeKbsRequiringReboot = value
    }

    /**
     * @param value Windows KBID to be excluded for patching.
     */
    @JvmName("mqnfhfsimuexgiwn")
    public suspend fun kbNumbersToExclude(`value`: Output<List<String>>) {
        this.kbNumbersToExclude = value
    }

    @JvmName("ntctltveodyxqaxx")
    public suspend fun kbNumbersToExclude(vararg values: Output<String>) {
        this.kbNumbersToExclude = Output.all(values.asList())
    }

    /**
     * @param values Windows KBID to be excluded for patching.
     */
    @JvmName("bfadshwxusoiwmlh")
    public suspend fun kbNumbersToExclude(values: List<Output<String>>) {
        this.kbNumbersToExclude = Output.all(values)
    }

    /**
     * @param value Windows KBID to be included for patching.
     */
    @JvmName("vtgekupnabbhjpxe")
    public suspend fun kbNumbersToInclude(`value`: Output<List<String>>) {
        this.kbNumbersToInclude = value
    }

    @JvmName("likytcgvofluagyq")
    public suspend fun kbNumbersToInclude(vararg values: Output<String>) {
        this.kbNumbersToInclude = Output.all(values.asList())
    }

    /**
     * @param values Windows KBID to be included for patching.
     */
    @JvmName("ieirpjymodcdoflu")
    public suspend fun kbNumbersToInclude(values: List<Output<String>>) {
        this.kbNumbersToInclude = Output.all(values)
    }

    /**
     * @param value Classification category of patches to be patched
     */
    @JvmName("hsnxynvicyubhcha")
    public suspend fun classificationsToInclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.classificationsToInclude = mapped
    }

    /**
     * @param values Classification category of patches to be patched
     */
    @JvmName("efsifydxipmfmcxv")
    public suspend fun classificationsToInclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.classificationsToInclude = mapped
    }

    /**
     * @param value Exclude patches which need reboot
     */
    @JvmName("gvjedoayrxillldn")
    public suspend fun excludeKbsRequiringReboot(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludeKbsRequiringReboot = mapped
    }

    /**
     * @param value Windows KBID to be excluded for patching.
     */
    @JvmName("bcvjhkoyyqrvyifm")
    public suspend fun kbNumbersToExclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kbNumbersToExclude = mapped
    }

    /**
     * @param values Windows KBID to be excluded for patching.
     */
    @JvmName("ytdivvtiirklbnmn")
    public suspend fun kbNumbersToExclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kbNumbersToExclude = mapped
    }

    /**
     * @param value Windows KBID to be included for patching.
     */
    @JvmName("sohvehucynaautwi")
    public suspend fun kbNumbersToInclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kbNumbersToInclude = mapped
    }

    /**
     * @param values Windows KBID to be included for patching.
     */
    @JvmName("nqnsjhlasrmurova")
    public suspend fun kbNumbersToInclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kbNumbersToInclude = mapped
    }

    internal fun build(): InputWindowsParametersArgs = InputWindowsParametersArgs(
        classificationsToInclude = classificationsToInclude,
        excludeKbsRequiringReboot = excludeKbsRequiringReboot,
        kbNumbersToExclude = kbNumbersToExclude,
        kbNumbersToInclude = kbNumbersToInclude,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/maintenance/kotlin/inputs/InputWindowsParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.maintenance.kotlin.inputs

import com.pulumi.azurenative.maintenance.inputs.InputWindowsParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Input properties for patching a Windows machine.
 * @property classificationsToInclude Classification category of patches to be patched
 * @property excludeKbsRequiringReboot Exclude patches which need reboot
 * @property kbNumbersToExclude Windows KBID to be excluded for patching.
 * @property kbNumbersToInclude Windows KBID to be included for patching.
 */
public data class InputWindowsParametersArgs(
    public val classificationsToInclude: Output<List<String>>? = null,
    public val excludeKbsRequiringReboot: Output<Boolean>? = null,
    public val kbNumbersToExclude: Output<List<String>>? = null,
    public val kbNumbersToInclude: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.maintenance.inputs.InputWindowsParametersArgs> {
    override fun toJava(): com.pulumi.azurenative.maintenance.inputs.InputWindowsParametersArgs =
        com.pulumi.azurenative.maintenance.inputs.InputWindowsParametersArgs.builder()
            .classificationsToInclude(
                classificationsToInclude?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .excludeKbsRequiringReboot(excludeKbsRequiringReboot?.applyValue({ args0 -> args0 }))
            .kbNumbersToExclude(kbNumbersToExclude?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .kbNumbersToInclude(
                kbNumbersToInclude?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [InputWindowsParametersArgs].
 */
@PulumiTagMarker
public class InputWindowsParametersArgsBuilder internal constructor() {
    private var classificationsToInclude: Output<List<String>>? = null

    private var excludeKbsRequiringReboot: Output<Boolean>? = null

    private var kbNumbersToExclude: Output<List<String>>? = null

    private var kbNumbersToInclude: Output<List<String>>? = null

    /**
     * @param value Classification category of patches to be patched
     */
    @JvmName("bmvgamxxmquyhydm")
    public suspend fun classificationsToInclude(`value`: Output<List<String>>) {
        this.classificationsToInclude = value
    }

    @JvmName("vtrqsxpfgpitoonk")
    public suspend fun classificationsToInclude(vararg values: Output<String>) {
        this.classificationsToInclude = Output.all(values.asList())
    }

    /**
     * @param values Classification category of patches to be patched
     */
    @JvmName("qhtxwdnbvahyodnu")
    public suspend fun classificationsToInclude(values: List<Output<String>>) {
        this.classificationsToInclude = Output.all(values)
    }

    /**
     * @param value Exclude patches which need reboot
     */
    @JvmName("twbktrphprdsfvom")
    public suspend fun excludeKbsRequiringReboot(`value`: Output<Boolean>) {
        this.excludeKbsRequiringReboot = value
    }

    /**
     * @param value Windows KBID to be excluded for patching.
     */
    @JvmName("qdjgomikkqlcgnfm")
    public suspend fun kbNumbersToExclude(`value`: Output<List<String>>) {
        this.kbNumbersToExclude = value
    }

    @JvmName("wkvkdblaqliuclmg")
    public suspend fun kbNumbersToExclude(vararg values: Output<String>) {
        this.kbNumbersToExclude = Output.all(values.asList())
    }

    /**
     * @param values Windows KBID to be excluded for patching.
     */
    @JvmName("emwflslhirahrotf")
    public suspend fun kbNumbersToExclude(values: List<Output<String>>) {
        this.kbNumbersToExclude = Output.all(values)
    }

    /**
     * @param value Windows KBID to be included for patching.
     */
    @JvmName("dlkfjccmndcrkymw")
    public suspend fun kbNumbersToInclude(`value`: Output<List<String>>) {
        this.kbNumbersToInclude = value
    }

    @JvmName("evowfmoioxvxtjeu")
    public suspend fun kbNumbersToInclude(vararg values: Output<String>) {
        this.kbNumbersToInclude = Output.all(values.asList())
    }

    /**
     * @param values Windows KBID to be included for patching.
     */
    @JvmName("ygbqilggrtvawlkx")
    public suspend fun kbNumbersToInclude(values: List<Output<String>>) {
        this.kbNumbersToInclude = Output.all(values)
    }

    /**
     * @param value Classification category of patches to be patched
     */
    @JvmName("scwueylawydaarir")
    public suspend fun classificationsToInclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.classificationsToInclude = mapped
    }

    /**
     * @param values Classification category of patches to be patched
     */
    @JvmName("mhswdnupuybyvitu")
    public suspend fun classificationsToInclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.classificationsToInclude = mapped
    }

    /**
     * @param value Exclude patches which need reboot
     */
    @JvmName("eibmdhagckrqntfx")
    public suspend fun excludeKbsRequiringReboot(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludeKbsRequiringReboot = mapped
    }

    /**
     * @param value Windows KBID to be excluded for patching.
     */
    @JvmName("rpaabcbetmriomyb")
    public suspend fun kbNumbersToExclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kbNumbersToExclude = mapped
    }

    /**
     * @param values Windows KBID to be excluded for patching.
     */
    @JvmName("ntfmxmhbhmpmrtln")
    public suspend fun kbNumbersToExclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kbNumbersToExclude = mapped
    }

    /**
     * @param value Windows KBID to be included for patching.
     */
    @JvmName("jdkyegnpaunpxmsu")
    public suspend fun kbNumbersToInclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kbNumbersToInclude = mapped
    }

    /**
     * @param values Windows KBID to be included for patching.
     */
    @JvmName("kyxrxqqlmfpswjuu")
    public suspend fun kbNumbersToInclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kbNumbersToInclude = mapped
    }

    internal fun build(): InputWindowsParametersArgs = InputWindowsParametersArgs(
        classificationsToInclude = classificationsToInclude,
        excludeKbsRequiringReboot = excludeKbsRequiringReboot,
        kbNumbersToExclude = kbNumbersToExclude,
        kbNumbersToInclude = kbNumbersToInclude,
    )
}
